@@ -3,15 +3,15 @@ import math
 
 # original source:  http://flask.pocoo.org/snippets/44/
 class Pagination(object):
-    def __init__(self, page, per_page, total_count, items):
+    def __init__(self, page, per_page, total, items):
         self.page = page
         self.per_page = per_page
-        self.total_count = total_count
+        self.total = total
         self.items = items
 
     @property
     def pages(self):
-        return int(math.ceil(self.total_count / float(self.per_page)))
+        return int(math.ceil(self.total / float(self.per_page)))
 
     @property
     def has_prev(self):
